@@ -1437,3 +1437,25 @@ class Generator:
 
     def kwarg_sql(self, expression: exp.Kwarg) -> str:
         return self.binary(expression, "=>")
+
+    def when_sql(self, expression: exp.When) -> str:
+        this = self.sql(expression, "this")
+        then_expression = expression.args.get("then")
+        if isinstance(then_expression, exp.Insert):
+            then = f"INSERT {self.sql(then_expression, 'this')}"
+            if "expression" in then_expression.args:
+                then += f" VALUES {self.sql(then_expression, 'expression')}"
+        elif isinstance(then_expression, exp.Update):
+            if isinstance(then_expression.args.get("expressions"), exp.Star):
+                then = f"UPDATE {self.sql(then_expression, 'expressions')}"
+            else:
+                then = f"UPDATE SET {self.expressions(then_expression, flat=True)}"
+        else:
+            then = self.sql(then_expression)
+        return f"WHEN {this} THEN {then}"
+
+    def merge_sql(self, expression: exp.Merge) -> str:
+        this = self.sql(expression, "this")
+        using = f"USING {self.sql(expression, 'using')}"
+        on = f"ON {self.sql(expression, 'on')}"
+        return f"MERGE INTO {this} {using} {on} {self.expressions(expression, sep=' ')}"
